//@line 36 "/builds/tinderbox/Fx-Mozilla1.8-l10n-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/locales/../../../l10n/it/browser/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Mozilla1.8-l10n-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/locales/../../../l10n/it/browser/firefox-l10n.js"

pref("general.useragent.locale", "it");
